@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -33,7 +32,7 @@
 #include "gtk-utils.h"
 #include "glib-utils.h"
 #include "preferences.h"
-#include "main.h"
+#include "fr-init.h"
 
 
 #define ARCHIVE_ICON_SIZE (48)
@@ -552,7 +551,7 @@ dlg_batch_add_files (FrWindow *window,
 
 	/* archive type combobox */
 
-	data->a_archive_type_combo_box = gtk_combo_box_new_text ();
+	data->a_archive_type_combo_box = gtk_combo_box_text_new ();
 	if (data->single_file)
 		data->supported_types = single_file_save_type;
 	else
@@ -560,8 +559,8 @@ dlg_batch_add_files (FrWindow *window,
 	sort_mime_types_by_extension (data->supported_types);
 
 	for (i = 0; data->supported_types[i] != -1; i++)
-		gtk_combo_box_append_text (GTK_COMBO_BOX (data->a_archive_type_combo_box),
-					   mime_type_desc[data->supported_types[i]].default_ext);
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (data->a_archive_type_combo_box),
+					        mime_type_desc[data->supported_types[i]].default_ext);
 
 	gtk_box_pack_start (GTK_BOX (a_archive_type_box), data->a_archive_type_combo_box, TRUE, TRUE, 0);
 	gtk_widget_show_all (a_archive_type_box);
